@@ -21,7 +21,17 @@ def set_async():
 
 
 class browser:
-    def __init__(self, url, language='en', proxy=None, find_redirect=False, api_url=None, debug=False, newParams=False, executablePath=None):
+    def __init__(
+        self,
+        url,
+        language="en",
+        proxy=None,
+        find_redirect=False,
+        api_url=None,
+        debug=False,
+        newParams=False,
+        executablePath=None,
+    ):
         self.url = url
         self.debug = debug
         self.proxy = proxy
@@ -38,31 +48,38 @@ class browser:
             "--window-position=0,0",
             "--ignore-certifcate-errors",
             "--ignore-certifcate-errors-spki-list",
-            "--user-agent=" + self.userAgent
+            "--user-agent=" + self.userAgent,
         ]
 
         if proxy != None:
             if "@" in proxy:
-                self.args.append("--proxy-server=" + proxy.split(":")[0] + "://" + proxy.split(
-                    "://")[1].split(":")[1].split("@")[1] + ":" + proxy.split("://")[1].split(":")[2])
+                self.args.append(
+                    "--proxy-server="
+                    + proxy.split(":")[0]
+                    + "://"
+                    + proxy.split("://")[1].split(":")[1].split("@")[1]
+                    + ":"
+                    + proxy.split("://")[1].split(":")[2]
+                )
             else:
                 self.args.append("--proxy-server=" + proxy)
         self.options = {
-            'args': self.args,
-            'headless': True,
-            'ignoreHTTPSErrors': True,
-            'userDataDir': "./tmp",
-            'handleSIGINT': False,
-            'handleSIGTERM': False,
-            'handleSIGHUP': False
+            "args": self.args,
+            "headless": True,
+            "ignoreHTTPSErrors": True,
+            "userDataDir": "./tmp",
+            "handleSIGINT": False,
+            "handleSIGTERM": False,
+            "handleSIGHUP": False,
+            "dumpio": True,
         }
 
         if self.executablePath != None:
-            self.options['executablePath'] = self.executablePath
+            self.options["executablePath"] = self.executablePath
 
         if async_support:
             loop = asyncio.new_event_loop()
-            t = Thread(target=self.__start_background_loop, args=(loop, ), daemon=True)
+            t = Thread(target=self.__start_background_loop, args=(loop,), daemon=True)
             t.start()
             if find_redirect:
                 fut = asyncio.run_coroutine_threadsafe(self.find_redirect(), loop)
@@ -115,45 +132,66 @@ class browser:
         self.browser = await pyppeteer.launch(self.options)
         self.page = await self.browser.newPage()
 
-        await self.page.evaluateOnNewDocument("""() => {
+        await self.page.evaluateOnNewDocument(
+            """() => {
     delete navigator.__proto__.webdriver;
-        }""")
+        }"""
+        )
 
         # Check for user:pass proxy
         if self.proxy != None:
             if "@" in self.proxy:
-                await self.page.authenticate({
-                    'username': self.proxy.split("://")[1].split(":")[0],
-                    'password': self.proxy.split("://")[1].split(":")[1].split("@")[0]
-                })
+                await self.page.authenticate(
+                    {
+                        "username": self.proxy.split("://")[1].split(":")[0],
+                        "password": self.proxy.split("://")[1]
+                        .split(":")[1]
+                        .split("@")[0],
+                    }
+                )
 
         await stealth(self.page)
 
         # might have to switch to a tiktok url if they improve security
-        await self.page.goto("about:blank", {
-            'waitUntil': "load"
-        })
+        await self.page.goto("about:blank", {"waitUntil": "load"})
 
-        self.userAgent = await self.page.evaluate("""() => {return navigator.userAgent; }""")
+        self.userAgent = await self.page.evaluate(
+            """() => {return navigator.userAgent; }"""
+        )
 
-        self.verifyFp = ''.join(random.choice(
-            string.ascii_lowercase + string.ascii_uppercase + string.digits) for i in range(16))
+        self.verifyFp = "".join(
+            random.choice(
+                string.ascii_lowercase + string.ascii_uppercase + string.digits
+            )
+            for i in range(16)
+        )
 
         self.did = str(random.randint(10000, 999999999))
 
         await self.page.evaluate("() => { " + get_acrawler() + " }")
-        self.signature = await self.page.evaluate('''() => {
-        var url = "''' + self.url + "&verifyFp=" + self.verifyFp + '''&did=''' + self.did + '''"
+        self.signature = await self.page.evaluate(
+            '''() => {
+        var url = "'''
+            + self.url
+            + "&verifyFp="
+            + self.verifyFp
+            + """&did="""
+            + self.did
+            + """"
         var token = window.byted_acrawler.sign({url: url});
         return token;
-        }''')
+        }"""
+        )
 
         if self.api_url != None:
-            await self.page.goto(self.url +
-                                 "&verifyFp=" + self.verifyFp +
-                                 "&_signature=" + self.signature, {
-                                     'waitUntil': "load"
-                                 })
+            await self.page.goto(
+                self.url
+                + "&verifyFp="
+                + self.verifyFp
+                + "&_signature="
+                + self.signature,
+                {"waitUntil": "load"},
+            )
 
             self.data = await self.page.content()
             # self.data = json.loads(self.data.replace("</pre></body></html>", "").replace(
@@ -167,17 +205,23 @@ class browser:
             self.browser = await pyppeteer.launch(self.options)
             self.page = await self.browser.newPage()
 
-            await self.page.evaluateOnNewDocument("""() => {
+            await self.page.evaluateOnNewDocument(
+                """() => {
         delete navigator.__proto__.webdriver;
-    }""")
+    }"""
+            )
 
             # Check for user:pass proxy
             if self.proxy != None:
                 if "@" in self.proxy:
-                    await self.page.authenticate({
-                        'username': self.proxy.split("://")[1].split(":")[0],
-                        'password': self.proxy.split("://")[1].split(":")[1].split("@")[0]
-                    })
+                    await self.page.authenticate(
+                        {
+                            "username": self.proxy.split("://")[1].split(":")[0],
+                            "password": self.proxy.split("://")[1]
+                            .split(":")[1]
+                            .split("@")[0],
+                        }
+                    )
 
             await stealth(self.page)
 
@@ -191,9 +235,7 @@ class browser:
 
             # await self.page.setUserAgent(self.userAgent)
 
-            await self.page.goto(self.url, {
-                'waitUntil': "load"
-            })
+            await self.page.goto(self.url, {"waitUntil": "load"})
 
             self.redirect_url = self.page.url
 
@@ -206,12 +248,12 @@ class browser:
 
     def __format_proxy(self, proxy):
         if proxy != None:
-            return {
-                'http': proxy,
-                'https': proxy
-            }
+            return {"http": proxy, "https": proxy}
         else:
             return None
 
     def __get_js(self, proxy=None):
-        return requests.get("https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js", proxies=self.__format_proxy(proxy)).text
+        return requests.get(
+            "https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js",
+            proxies=self.__format_proxy(proxy),
+        ).text
